@@ -25,7 +25,7 @@
 #include "graveman.h"
 
 /* appele pour chaque entree de la liste */
-gboolean foreachpistes(GtkTreeModel *Amodel, GtkTreePath *Apath, GtkTreeIter *Aiter, gpointer Adata)
+gboolean foreachtracks(GtkTreeModel *Amodel, GtkTreePath *Apath, GtkTreeIter *Aiter, gpointer Adata)
 {
   GHashTable *Lhash = (GHashTable *) Adata;
   GtkLabel *LTitle = GTK_LABEL(g_hash_table_lookup(Lhash, "gravetitle"));
@@ -83,8 +83,11 @@ gchar *make_audio_fileslist(gint Anbrfiles)
   
 gboolean preparetrack(GHashTable *Ahash, GError **Aerror) {
   gchar **Ltmpdir = (gchar **)g_hash_table_lookup(Ahash, "tmpdir");
+  gboolean *Labort = (gboolean *)g_hash_table_lookup(Ahash, "gabort");
+  gint *Lcont = (gint *)g_hash_table_lookup(Ahash, "cont");
   gchar *Lnamedir;
   GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(GTK_TREE_VIEW(g_hash_table_lookup(Ahash, "LISTEAUDIO")));
+  GtkProgressBar *Lprogressbar2 = GTK_PROGRESS_BAR(g_hash_table_lookup(Ahash, "pb_step"));
   g_assert(GTK_IS_TREE_MODEL(Ltreemodel));
 
   Lnamedir = g_strdup_printf("%s/%s", conf_get_string_def("tmpdir", "/tmp"), "gravemanXXXXXX");
@@ -98,8 +101,20 @@ gboolean preparetrack(GHashTable *Ahash, GError **Aerror) {
 
   *Ltmpdir = Lnamedir;
 
+  *Lcont = 2;
+  g_timeout_add(500, encours_callback, Ahash);
+
   /* conversion de chaques fichiers */
-  gtk_tree_model_foreach(Ltreemodel, foreachpistes, Ahash);
+  gtk_tree_model_foreach(Ltreemodel, foreachtracks, Ahash);
+
+  /* on attend la fin du timeout */
+  *Lcont = 1;
+  while (*Lcont > 0) gtk_main_iteration(); 
+
+  gtk_progress_bar_set_fraction(Lprogressbar2, 0);
+  gtk_progress_bar_set_text(GTK_PROGRESS_BAR(Lprogressbar2), "0%");
+
+  if (*Labort==TRUE) return FALSE;
 
   if ((GError *)*Aerror) {
     deltempdir(Lnamedir);
