@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  * MA 02111-1307, USA. 
  * 
- * URL: http://scresto.site.voite.fr/
+ * URL: http://www.nongnu.org/graveman/
  *
  */
 
@@ -34,6 +34,7 @@
 #include <ctype.h>
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <fcntl.h>
 #include <math.h>
 #include <glib/gprintf.h>
 #include "config.h"
@@ -46,6 +47,7 @@
 
 /* convertire un texte en utf8 */
 #define _UTF8(texte) g_locale_to_utf8(texte, -1, NULL, NULL, NULL)
+#define _FILEUTF8(texte) g_filename_to_utf8(texte, -1, NULL, NULL, NULL)
 /* recupere un nom de fichier de puis de l'utf8 */
 #define _FILENAME(texte) g_filename_from_utf8(texte, -1, NULL, NULL, NULL)
 /* message warning + affiche errno en utf8 */
@@ -124,9 +126,6 @@ typedef enum {
   #define MAXPATHLEN 2048
 #endif
 
-#define INIT_GDRIVES(quel) Gldrives[quel].type = Gldrives[quel].vitesse = -1; \
-                           *Gldrives[quel].dev = *Gldrives[quel].name = 0
-
 typedef struct {
   Ttypeconf type;
   gchar *entry;
@@ -134,21 +133,32 @@ typedef struct {
   gchar *defaultvalue;
 } TProgRequis;
 
+#define _OTHER_DEVICE 0
 #define _READ_CDR     1
 #define _WRITE_CDR    2
 #define _WRITE_CDRW   4
 #define _WRITE_DUMMY  8
-#define DRIVE_READER(value) (Gldrives[value].type & _READ_CDR)
-#define DRIVE_WRITER(value) (Gldrives[value].type & _WRITE_CDR)
-#define DRIVE_CDRW_WRITER(value) (Gldrives[value].type & _WRITE_CDRW)
-#define DRIVE_ICONE(value) (Gldrives[value].type & _WRITE_CDR) ? GCDRWpetiteIcone : GCDpetiteIcone
+#define DRIVE_READER(drive) (drive && (drive->type & _READ_CDR))
+#define DRIVE_WRITER(drive) (drive && (drive->type & _WRITE_CDR))
+#define DRIVE_CDRW_WRITER(drive) (drive && (drive->type & _WRITE_CDRW))
+#define DRIVE_ICONE(drive) (drive->type & _WRITE_CDR) ? GCDRWpetiteIcone : GCDpetiteIcone
 
 typedef struct {
-  char name[256];
-  char dev[64];
-  int  type;
-  short vitesse;
-} Tdrive_info;
+  gchar *name;  /* label du lecteur */
+  GSList *dev;   /* peripheriques */
+  GSList *bus;   /* liste des bus */
+  gint actuperiph;
+  gint  type;   /* type 15 = graveur cdrw, 1 = lecteur */
+  gshort vitesse;
+  gboolean manual;  /* ajouter manuelement ou non */
+} Tdriveinfo;
+
+typedef struct {
+  gchar *detectline;
+  gchar *useline;
+  gchar *bus;
+  gint priority;
+} Tsearchdrive;
 
 typedef struct {
   gchar *basecode;
@@ -190,6 +200,7 @@ extern GtkWidget* create_addfileselection (GtkWindow *AParent);
 extern GtkWidget* create_adddirselection (GtkWindow *AParent);
 extern GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, GHashTable *Ahash);
 extern GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash);
+extern GtkMenu *create_gtkpopupmenudevices(GtkWidget *Aliste, GHashTable *Ahash);
 extern gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern GtkWidget* create_addpisteselection (GtkWindow *AParent);
 extern GladeXML *create_window_encours(GtkWidget *AParent);
@@ -210,6 +221,9 @@ extern void prepare_disable_when_iso(GHashTable *Ahash, gchar *Abasename, const
 extern void prepare_disable_when_notcdrw(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...);
 extern void show_erasecdrwwindow(GHashTable *Ahash);
 extern void show_fixcdwindow(GHashTable *Ahash);
+extern void manage_combobox_devicebus(GtkComboBox *Acombobox, Tdriveinfo *Adrive);
+extern GHashTable *create_dialog_edit_device(GtkWidget *Aparent, Tdriveinfo *Adrive);
+extern GHashTable *create_dialog_add_device(GtkWidget *Aparent);
 extern GHashTable *addmediaformat(GHashTable *Aparent);
 
 /* log.c */
@@ -241,22 +255,25 @@ extern gboolean read_config(GError **Aerror);
 extern void restore_main_window_pos(GtkWidget *Awindow1);
 
 /* matos.c */
-extern Tdrive_info Gldrives[128];
-extern unsigned int Gnumdrives;
-extern Tdrive_info *findlecteur(gchar *Aname);
+extern GSList *Glistdrives;
+extern void append_this_drive(Tdriveinfo *Adrive);
+extern void free_this_drive(Tdriveinfo *Adrive);
+extern void free_drives(gboolean Aremovemanu);
+extern void insert_or_update_drive(gchar *Adev, gchar *Amarque, gchar *Amodel, gchar *Aquoi, Tsearchdrive *Adrivedesc);
+extern Tdriveinfo *find_drive(gchar *Aident);
 extern gint get_maxspeed(int Anum);
 extern gboolean burn_data(GHashTable *Ahash, GError **Aerror);
 extern gboolean burn_audio(GHashTable *Ahash, GError **Aerror);
 extern gboolean burn_copy(GHashTable *Ahash, GError **Aerror);
 extern gboolean deltempdir(gchar *Ldirpath);
-extern gboolean is_duplicate_drives(gchar *Abustype, gchar *Adev);
+extern void put_devicelabel(Tdriveinfo *Adrive, gchar *Abuf, gint Asizemax);
 
 /* cdrecord.c */
 extern gchar *burn_data_getextrapara(GHashTable *Ahash);
-extern int scan_for_drives(GError **Aerror);
+extern int scan_for_drives(GHashTable *Ahash, GError **Aerror);
 extern gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror);
 extern gboolean gravepiste(GHashTable *Ahash, GError **Aerror);
-extern gboolean maj_drive_info(gint Anumdrive, GError **Aerror);
+extern gboolean maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror);
 extern gboolean perform_erase_cdrw(GHashTable *Ahash, GError **Aerror);
 extern gboolean perform_fix_cd(GHashTable *Ahash, GError **Aerror);
 
@@ -276,6 +293,7 @@ extern gchar *belleHeure(gchar *Abuf, gchar *Adst);
 extern gint sc_strcountv(gchar **Aarray);
 extern void sc_strstripv(gchar **Aarray);
 extern gchar *get_combo_value(GtkWidget *Acombo);
+extern gint get_combo_intvalue(GtkWidget *Acombo);
 extern gint make_int(gchar *Abuf);
 extern gshort make_short(gchar *Abuf);
 extern gchar *sc_realloc_cat(gchar *Asep, gchar *Asrc, gchar *Aplus);
@@ -309,6 +327,9 @@ extern void glade_to_hash_list(GladeXML *Axml, GHashTable *Ahash, const gchar *A
 extern GtkWidget *sc_glade_xml_get_widgetv(GladeXML *Axml, const gchar *Akeyformat, ...);
 
 /* callbacks.c */
+extern void gtk_devices_edit(GtkWidget *Abtn, gpointer Adata);
+extern void gtk_devices_remove(GtkWidget *Abtn, gpointer Adata);
+extern void gtk_devices_add(GtkWidget *Abtn, gpointer Adata);
 extern gboolean encours_callback(gpointer Adata);
 extern void on_about (GtkMenuItem *Amenuitem, gpointer Adata);
 extern gboolean on_closeabout (GtkWidget *Awidget, GdkEventButton *Aevent, gpointer Adata);
@@ -320,7 +341,7 @@ extern void gtk_file_sel(GtkWidget *Abtn, gpointer Adata);
 extern void confirm_erasecdrw (GtkWidget *Abtn, gpointer Adata);
 extern void confirm_fixcd (GtkWidget *Abtn, gpointer Adata);
 extern void confirm_burn (GtkWidget *Abtn, gpointer Adata);
-extern void abort_gravure (GtkWidget *Abtn, gpointer Adata);
+extern gboolean abort_gravure (GtkWidget *Abtn, gpointer Adata);
 extern void gtk_data_addfile(GtkWidget *Abtn, gpointer Adata);
 extern void gtk_data_adddirectory(GtkWidget *Abtn, gpointer Adata);
 extern void gtk_data_removefiles(GtkWidget *Abtn, gpointer Adata);
@@ -343,7 +364,11 @@ extern void abort_encours(GtkWidget *Abtn, gpointer Adata);
 extern void menu_quit(GtkWidget *Aobj1, gpointer Adata);
 extern void delete_event_quit(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
 extern void view_popupmenu_addaudio(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
+extern void key_popupmenu_addaudio(GtkWidget *Aliste, gpointer Adata);
 extern void view_popupmenu_addfile(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
+extern void key_popupmenu_addfile(GtkWidget *Aliste, gpointer Adata);
+extern void view_popupmenu_devices(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
+extern void key_popupmenu_devices(GtkWidget *Aliste, gpointer Adata);
 extern void change_remplissage(GtkWidget *Acombo, gpointer Adata);
 extern gboolean on_select_files (GtkTreeSelection *Aselection, GtkTreeModel *Amodel,
                        GtkTreePath *Apath, gboolean Apath_currently_selected, gpointer Adata);
@@ -354,6 +379,8 @@ extern void on_addmediaformat(GtkWidget *Abtn, gpointer Adata);
 extern void update_media_unit(GtkWidget *Acombo, gpointer Adata);
 extern gboolean update_media_fields(GtkWidget *Awidget, gpointer Adata);
 extern void gtk_def_imageboot(GtkWidget *Abtn, gpointer Adata);
+extern gboolean quit_property(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
+extern gboolean on_deleteevent_gravure(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
 
 /*
  * vim:et:ts=8:sts=2:sw=2
